=====================
 nti.externalization
=====================

.. image:: https://img.shields.io/pypi/v/nti.externalization.svg
        :target: https://pypi.python.org/pypi/nti.externalization/
        :alt: Latest release

.. image:: https://img.shields.io/pypi/pyversions/nti.externalization.svg
        :target: https://pypi.org/project/nti.externalization/
        :alt: Supported Python versions

.. image:: https://github.com/NextThought/nti.externalization/workflows/tests/badge.svg
        :target: https://github.com/NextThought/nti.externalization/actions?query=workflow%3Atests

.. image:: https://coveralls.io/repos/github/NextThought/nti.externalization/badge.svg?branch=master
        :target: https://coveralls.io/github/NextThought/nti.externalization?branch=master

.. image:: https://readthedocs.org/projects/ntiexternalization/badge/?version=latest
        :target: https://ntiexternalization.readthedocs.io/en/latest/
        :alt: Documentation Status

A flexible, schema-driven system for converting Python objects to and
from external formats such as JSON and YAML. This works well in a
zope.component environment such as Pyramid.

Documentation is hosted at https://ntiexternalization.readthedocs.io/
